"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RunsClient = void 0;
/**
 * RunsClient is used to list and manage runs
 */
class RunsClient {
    constructor(client) {
        this.api = client.api;
        this.tenantId = client.tenantId;
        this.workflows = client.workflows;
    }
    get(run) {
        return __awaiter(this, void 0, void 0, function* () {
            const runId = typeof run === 'string' ? run : yield run.getWorkflowRunId();
            const { data } = yield this.api.workflowRunGet(this.tenantId, runId);
            return data;
        });
    }
    getDetails(run) {
        return __awaiter(this, void 0, void 0, function* () {
            const runId = typeof run === 'string' ? run : yield run.getWorkflowRunId();
            const { data } = yield this.api.workflowRunGetShape(this.tenantId, runId);
            return data;
        });
    }
    list(opts) {
        return __awaiter(this, void 0, void 0, function* () {
            // TODO workflow id on opts is a uuid
            const { data } = yield this.api.workflowRunList(this.tenantId, opts);
            return data;
        });
    }
    cancel(opts) {
        return __awaiter(this, void 0, void 0, function* () {
            const filter = opts.filters && (yield this.prepareFilter(opts.filters));
            return this.api.v1TaskCancel(this.tenantId, {
                externalIds: opts.ids,
                filter,
            });
        });
    }
    replay(opts) {
        return __awaiter(this, void 0, void 0, function* () {
            const filter = opts.filters && (yield this.prepareFilter(opts.filters));
            return this.api.v1TaskReplay(this.tenantId, {
                externalIds: opts.ids,
                filter,
            });
        });
    }
    prepareFilter(_a) {
        return __awaiter(this, arguments, void 0, function* ({ since, until, statuses, workflowNames, additionalMetadata, }) {
            return {
                since: since.toISOString(),
                until: until === null || until === void 0 ? void 0 : until.toISOString(),
                statuses,
                workflowIds: yield Promise.all((workflowNames === null || workflowNames === void 0 ? void 0 : workflowNames.map((name) => __awaiter(this, void 0, void 0, function* () { return (yield this.workflows.get(name)).metadata.id; }))) || []),
                additionalMetadata: Object.entries(additionalMetadata || {}).map(([key, value]) => `${key}:${value}`),
            };
        });
    }
}
exports.RunsClient = RunsClient;
